@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
 from Acquisition import aq_base
 from Acquisition import aq_inner
-from Products.CMFPlone.interfaces import ISiteSchema
 from plone.app.contenttypes import _
+from plone.app.contenttypes.behaviors.leadimage import ILeadImage
+from plone.app.vocabularies.metadatafields import get_field_label
 from plone.app.contenttypes.interfaces import IFolder
 from plone.app.contenttypes.interfaces import IImage
 from plone.event.interfaces import IEvent
 from plone.memoize.view import memoize
 from plone.registry.interfaces import IRegistry
+from Products.CMFPlone.interfaces import ISiteSchema
 from Products.CMFPlone.PloneBatch import Batch
 from Products.CMFPlone.utils import safe_callable
 from Products.Five import BrowserView
@@ -166,6 +168,12 @@ class FolderView(BrowserView):
             ret.append('ModificationDate')
         return ret
 
+    def tabular_field_label(self, field):
+        """Return the internationalized label (Message object) corresponding
+           to the field.
+        """
+        return get_field_label(field)
+
     def tabular_fielddata(self, item, fieldname):
         value = getattr(item, fieldname, '')
         if safe_callable(value):
@@ -207,9 +215,13 @@ class FolderView(BrowserView):
     def album_images(self):
         """Get all images within this folder.
         """
+        provides = [
+            IImage.__identifier__,
+            ILeadImage.__identifier__,
+        ]
         images = self.results(
             batch=False,
-            object_provides=IImage.__identifier__
+            object_provides=provides
         )
         return images
 
