@@ -484,6 +484,7 @@ def migrateCustomAT(fields_mapping,
                     dry_run=False,
                     patch_linkintegrity=False,
                     patch_searchabletext=False,
+                    query=None,
                     ):
     """
     Try to get types infos from archetype_tool, then set a migrator and pass it
@@ -524,6 +525,8 @@ def migrateCustomAT(fields_mapping,
             is_folderish = getattr(src_obj, 'isPrincipiaFolderish', False)
             src_meta_type = src_obj.meta_type
     else:
+        # fallback
+        is_folderish = False
         # Get info from at-fti
         src_meta_type = fti.content_meta_type
         archetype_tool = getToolByName(portal, 'archetype_tool', None)
@@ -533,6 +536,7 @@ def migrateCustomAT(fields_mapping,
             if info.get('meta_type') == src_meta_type:
                 klass = info.get('klass', None)
                 is_folderish = klass.isPrincipiaFolderish
+                break
 
     migrator = makeCustomATMigrator(context=portal,
                                     src_type=src_type,
@@ -551,6 +555,8 @@ def migrateCustomAT(fields_mapping,
                            'src_meta_type': src_meta_type,
                            'dst_meta_type': '',
                            'use_savepoint': True}
+        if query:
+            walker_settings['query'] = query
         if dry_run:
             walker_settings['limit'] = 1
         walker = CustomQueryWalker(**walker_settings)
